<a href="https://github.com/texnoforge/texnomagic/releases" alt="latest release"><img src="https://img.shields.io/github/v/release/texnoforge/texnomagic"/></a>
<a href="https://pypi.org/project/texnomagic/" alt="pypi version"><img src="https://img.shields.io/pypi/v/texnomagic?color=blue"/></a>
<a href="https://github.com/texnoforge/texnomagic/actions/workflows/python-package.yml" alt="CI"><img src="https://img.shields.io/github/workflow/status/texnoforge/texnomagic/Python%20package/master?label=CI"/></a>
<a href="https://texnoforge.github.io/texnomagic/" alt="docs"><img src="https://img.shields.io/github/workflow/status/texnoforge/texnomagic/Deploy%20docs/master?label=docs"/></a>


# [TexnoMagic docs online][docs]

## [TexnoMagic docs on GitLab](https://github.com/texnoforge/texnomagic/tree/master/docs)

## TexnoMagic docs offline

See docs/index.md and other files in docs/ directory.

You can also render docs into HTML using portray:

    pip install portray
    protray as_html

#### read the [docs] and have a nice magic ᕕ( ᐛ )ᕗ

[docs]: http://texnoforge.github.io/texnomagic
